# pydockermon [![Build Status](https://travis-ci.com/ludeeus/pydockermon.svg?branch=master)](https://travis-ci.com/ludeeus/pydockermon) [![PyPI version](https://badge.fury.io/py/pydockermon.svg)](https://badge.fury.io/py/pydockermon)

_Python API wrapper for HA Dockermon.._

## Install

```bash
pip install pydockermon
```

Look at the file `example.py` for a usage example.